summaryrefslogtreecommitdiffstats
path: root/openbb_platform/core/openbb_core/provider/standard_models/cash_flow.py
diff options
context:
space:
mode:
Diffstat (limited to 'openbb_platform/core/openbb_core/provider/standard_models/cash_flow.py')
-rw-r--r--openbb_platform/core/openbb_core/provider/standard_models/cash_flow.py10
1 files changed, 8 insertions, 2 deletions
diff --git a/openbb_platform/core/openbb_core/provider/standard_models/cash_flow.py b/openbb_platform/core/openbb_core/provider/standard_models/cash_flow.py
index a2495a26da1..c3c12e777bb 100644
--- a/openbb_platform/core/openbb_core/provider/standard_models/cash_flow.py
+++ b/openbb_platform/core/openbb_core/provider/standard_models/cash_flow.py
@@ -24,10 +24,16 @@ class CashFlowStatementQueryParams(QueryParams):
@field_validator("symbol", mode="before", check_fields=False)
@classmethod
- def upper_symbol(cls, v: str):
- """Convert symbol to uppercase."""
+ def to_upper(cls, v: str):
+ """Convert field to uppercase."""
return v.upper()
+ @field_validator("period", mode="before", check_fields=False)
+ @classmethod
+ def to_lower(cls, v: Optional[str]) -> Optional[str]:
+ """Convert field to lowercase."""
+ return v.lower() if v else v
+
class CashFlowStatementData(Data):
"""Cash Flow Statement Data."""